@@ -4,32 +4,44 @@
 
 -- Convenience view to list all hypertables
 CREATE OR REPLACE VIEW timescaledb_information.hypertables AS
-SELECT ht.schema_name AS hypertable_schema,
+WITH
+  hypertable_info AS (
+    SELECT hypertable_id, schema_name, table_name,
+           num_dimensions, compression_state, column_name,
+           column_type, interval_length,
+           (compression_state = 1) AS compression_enabled,
+           row_number() OVER (PARTITION BY hypertable_id ORDER BY di.id) AS dimension_num
+      FROM _timescaledb_catalog.hypertable ht
+      JOIN _timescaledb_catalog.dimension di ON ht.id = di.hypertable_id
+  )
+SELECT
+  ht.schema_name AS hypertable_schema,
   ht.table_name AS hypertable_name,
   t.tableowner AS owner,
   ht.num_dimensions,
   (
     SELECT count(1)
     FROM _timescaledb_catalog.chunk ch
-    WHERE ch.hypertable_id = ht.id AND ch.dropped IS FALSE AND ch.osm_chunk IS FALSE) AS num_chunks,
-  (
-    CASE WHEN compression_state = 1 THEN
-      TRUE
-    ELSE
-      FALSE
-    END) AS compression_enabled,
-  srchtbs.tablespace_list AS tablespaces
-FROM _timescaledb_catalog.hypertable ht
-  INNER JOIN pg_tables t ON ht.table_name = t.tablename
-    AND ht.schema_name = t.schemaname
-  LEFT OUTER JOIN _timescaledb_catalog.continuous_agg ca ON ca.mat_hypertable_id = ht.id
-  LEFT OUTER JOIN (
+    WHERE ch.hypertable_id = ht.hypertable_id
+      AND ch.dropped IS FALSE
+      AND ch.osm_chunk IS FALSE
+  ) AS num_chunks,
+  ht.compression_enabled,
+  srchtbs.tablespace_list AS tablespaces,
+  ht.column_name AS primary_dimension,
+  ht.column_type AS primary_dimension_type
+FROM hypertable_info ht
+JOIN pg_tables t ON ht.table_name = t.tablename AND ht.schema_name = t.schemaname
+LEFT JOIN _timescaledb_catalog.continuous_agg ca ON ca.mat_hypertable_id = ht.hypertable_id
+LEFT JOIN (
     SELECT hypertable_id,
       array_agg(tablespace_name ORDER BY id) AS tablespace_list
     FROM _timescaledb_catalog.tablespace
-    GROUP BY hypertable_id) srchtbs ON ht.id = srchtbs.hypertable_id
+    GROUP BY hypertable_id) srchtbs ON ht.hypertable_id = srchtbs.hypertable_id
 WHERE ht.compression_state != 2 --> no internal compression tables
-  AND ca.mat_hypertable_id IS NULL;
+  AND ca.mat_hypertable_id IS NULL
+  AND ht.interval_length IS NOT NULL
+  AND ht.dimension_num = 1;
 
 CREATE OR REPLACE VIEW timescaledb_information.job_stats AS
 SELECT ht.schema_name AS hypertable_schema,
@@ -86,13 +98,14 @@ SELECT j.id AS job_id,
   j.config,
   js.next_start,
   j.initial_start,
-  ht.schema_name AS hypertable_schema,
-  ht.table_name AS hypertable_name,
+  COALESCE(ca.user_view_schema, ht.schema_name) AS hypertable_schema,
+  COALESCE(ca.user_view_name, ht.table_name) AS hypertable_name,
   j.check_schema,
   j.check_name
 FROM _timescaledb_config.bgw_job j
   LEFT JOIN _timescaledb_catalog.hypertable ht ON ht.id = j.hypertable_id
-  LEFT JOIN _timescaledb_internal.bgw_job_stat js ON js.job_id = j.id;
+  LEFT JOIN _timescaledb_internal.bgw_job_stat js ON js.job_id = j.id
+  LEFT JOIN _timescaledb_catalog.continuous_agg ca ON ca.mat_hypertable_id = j.hypertable_id;
 
 -- views for continuous aggregate queries ---
 CREATE OR REPLACE VIEW timescaledb_information.continuous_aggregates AS
@@ -109,7 +122,11 @@ SELECT ht.schema_name AS hypertable_schema,
   mat_ht.schema_name AS materialization_hypertable_schema,
   mat_ht.table_name AS materialization_hypertable_name,
   directview.viewdefinition AS view_definition,
-  cagg.finalized
+  cagg.finalized,
+  CASE WHEN _timescaledb_functions.has_invalidation_trigger(format('%I.%I', ht.schema_name, ht.table_name)::regclass)
+       THEN 'trigger'
+       ELSE 'wal'
+  END AS invalidate_using
 FROM _timescaledb_catalog.continuous_agg cagg,
   _timescaledb_catalog.hypertable ht,
   LATERAL (
@@ -358,7 +375,8 @@ CREATE OR REPLACE VIEW timescaledb_information.hypertable_compression_settings A
 		format('%I.%I',ht.schema_name,ht.table_name)::regclass AS hypertable,
 		array_to_string(segmentby,',') AS segmentby,
 		un.orderby,
-    d.compress_interval_length
+    d.compress_interval_length,
+    s.index AS index
   FROM _timescaledb_catalog.hypertable ht
   JOIN LATERAL (
     SELECT
@@ -386,7 +404,8 @@ CREATE OR REPLACE VIEW timescaledb_information.chunk_compression_settings AS
 		format('%I.%I',ht.schema_name,ht.table_name)::regclass AS hypertable,
 		format('%I.%I',ch.schema_name,ch.table_name)::regclass AS chunk,
 		array_to_string(segmentby,',') AS segmentby,
-		un.orderby
+		un.orderby,
+    s.index AS index
 	FROM _timescaledb_catalog.hypertable ht
     INNER JOIN _timescaledb_catalog.chunk ch ON ch.hypertable_id = ht.id
     INNER JOIN _timescaledb_catalog.compression_settings s ON (format('%I.%I',ch.schema_name,ch.table_name)::regclass = s.relid)
@@ -409,4 +428,3 @@ CREATE OR REPLACE VIEW timescaledb_information.chunk_columnstore_settings AS
 SELECT * FROM timescaledb_information.chunk_compression_settings;
 
 GRANT SELECT ON ALL TABLES IN SCHEMA timescaledb_information TO PUBLIC;
-
