@@ -672,7 +672,13 @@ get_job_lock_for_delete(int32 job_id)
 		if (VirtualTransactionIdIsValid(*vxid))
 		{
 			proc = VirtualTransactionGetProcCompat(vxid);
-			if (proc != NULL && proc->isBackgroundWorker)
+			if (proc != NULL
+#if PG18_LT
+				&& proc->isBackgroundWorker
+#else
+				&& !proc->isRegularBackend
+#endif
+			)
 			{
 				/* Simply assuming that this pid corresponds to the background worker
 				 * running the job is not sufficient. The scheduler could also be the
@@ -1244,6 +1250,7 @@ ts_bgw_job_entrypoint(PG_FUNCTION_ARGS)
 			/* If there was an error, rollback what was done before the error */
 			AbortCurrentTransaction();
 		StartTransactionCommand();
+		PushActiveSnapshot(GetTransactionSnapshot());
 
 		/* Free the old job if it exists, it's no longer needed, and since it's
 		 * in the TopMemoryContext it won't be freed otherwise.
@@ -1293,6 +1300,7 @@ ts_bgw_job_entrypoint(PG_FUNCTION_ARGS)
 		 */
 		elog(LOG, "job %d threw an error", params.job_id);
 
+		PopActiveSnapshot();
 		CommitTransactionCommand();
 		ReThrowError(edata);
 	}
