@@ -278,12 +278,10 @@ ts_chunk_constraint_dimensional_create(const Dimension *dim, const DimensionSlic
 									   const char *name)
 {
 	Constraint *constr = NULL;
-	bool isvarlena;
 	Node *dimdef;
 	ColumnRef *colref;
-	Datum startdat, enddat;
 	List *compexprs = NIL;
-	Oid outfuncid;
+	Oid type;
 
 	if (slice->fd.range_start == PG_INT64_MIN && slice->fd.range_end == PG_INT64_MAX)
 		return NULL;
@@ -308,16 +306,12 @@ ts_chunk_constraint_dimensional_create(const Dimension *dim, const DimensionSlic
 			/* The dimension has a time function to compute the time value so
 			 * need to convert the range values to the time type returned by
 			 * the partitioning function. */
-			getTypeOutputInfo(partinfo->partfunc.rettype, &outfuncid, &isvarlena);
-			startdat = ts_internal_to_time_value(slice->fd.range_start, partinfo->partfunc.rettype);
-			enddat = ts_internal_to_time_value(slice->fd.range_end, partinfo->partfunc.rettype);
+			type = partinfo->partfunc.rettype;
 		}
 		else
 		{
-			/* Closed dimension, just use the integer output function */
-			getTypeOutputInfo(INT8OID, &outfuncid, &isvarlena);
-			startdat = Int64GetDatum(slice->fd.range_start);
-			enddat = Int64GetDatum(slice->fd.range_end);
+			/* Closed dimension, just use the INT8 type */
+			type = INT8OID;
 		}
 	}
 	else
@@ -326,28 +320,24 @@ ts_chunk_constraint_dimensional_create(const Dimension *dim, const DimensionSlic
 		Assert(IS_OPEN_DIMENSION(dim));
 
 		dimdef = (Node *) colref;
-		getTypeOutputInfo(dim->fd.column_type, &outfuncid, &isvarlena);
-		startdat = ts_internal_to_time_value(slice->fd.range_start, dim->fd.column_type);
-		enddat = ts_internal_to_time_value(slice->fd.range_end, dim->fd.column_type);
+		type = dim->fd.column_type;
 	}
 
 	/*
-	 * Convert internal format datums to string (output) datums.
-	 *
 	 * We are forcing ISO datestyle here to prevent parsing errors with
 	 * certain timezone/datestyle combinations.
 	 */
 	int current_datestyle = DateStyle;
 	DateStyle = USE_ISO_DATES;
-	startdat = OidFunctionCall1(outfuncid, startdat);
-	enddat = OidFunctionCall1(outfuncid, enddat);
+	char *start_str = ts_internal_to_time_string(slice->fd.range_start, type);
+	char *end_str = ts_internal_to_time_string(slice->fd.range_end, type);
 	DateStyle = current_datestyle;
 
 	/* Elide range constraint for +INF or -INF */
 	if (slice->fd.range_start != PG_INT64_MIN)
 	{
 		A_Const *start_const = makeNode(A_Const);
-		memcpy(&start_const->val, makeString(DatumGetCString(startdat)), sizeof(start_const->val));
+		memcpy(&start_const->val, makeString(start_str), sizeof(start_const->val));
 		start_const->location = -1;
 		A_Expr *ge_expr = makeSimpleA_Expr(AEXPR_OP, ">=", dimdef, (Node *) start_const, -1);
 		compexprs = lappend(compexprs, ge_expr);
@@ -356,7 +346,7 @@ ts_chunk_constraint_dimensional_create(const Dimension *dim, const DimensionSlic
 	if (slice->fd.range_end != PG_INT64_MAX)
 	{
 		A_Const *end_const = makeNode(A_Const);
-		memcpy(&end_const->val, makeString(DatumGetCString(enddat)), sizeof(end_const->val));
+		memcpy(&end_const->val, makeString(end_str), sizeof(end_const->val));
 		end_const->location = -1;
 		A_Expr *lt_expr = makeSimpleA_Expr(AEXPR_OP, "<", dimdef, (Node *) end_const, -1);
 		compexprs = lappend(compexprs, lt_expr);
@@ -368,6 +358,9 @@ ts_chunk_constraint_dimensional_create(const Dimension *dim, const DimensionSlic
 	constr->deferrable = false;
 	constr->skip_validation = true;
 	constr->initially_valid = true;
+#if PG18_GE
+	constr->is_enforced = true;
+#endif
 
 	Assert(list_length(compexprs) >= 1);
 
@@ -435,34 +428,6 @@ create_non_dimensional_constraint(const ChunkConstraint *cc, Oid chunk_oid, int3
 		ts_process_utility_set_expect_chunk_modification(false);
 	}
 
-	/*
-	 * The table constraint might not have been created if this constraint
-	 * corresponds to a dimension slice that covers the entire range of values
-	 * in the particular dimension. In that case, there is no need to add a
-	 * table constraint.
-	 */
-	if (!OidIsValid(chunk_constraint_oid))
-		return InvalidOid;
-
-	Oid hypertable_constraint_oid =
-		get_relation_constraint_oid(hypertable_oid,
-									NameStr(cc->fd.hypertable_constraint_name),
-									false);
-	HeapTuple tuple = SearchSysCache1(CONSTROID, hypertable_constraint_oid);
-
-	if (HeapTupleIsValid(tuple))
-	{
-		FormData_pg_constraint *constr = (FormData_pg_constraint *) GETSTRUCT(tuple);
-
-		if (OidIsValid(constr->conindid) && constr->contype != CONSTRAINT_FOREIGN)
-			ts_chunk_index_create_from_constraint(hypertable_id,
-												  hypertable_constraint_oid,
-												  chunk_id,
-												  chunk_constraint_oid);
-
-		ReleaseSysCache(tuple);
-	}
-
 	return chunk_constraint_oid;
 }
 
@@ -915,33 +880,6 @@ hypertable_constraint_matches_tuple(TupleInfo *ti, const char *hypertable_constr
 	return !isnull && namestrcmp(DatumGetName(name), hypertable_constraint_name) == 0;
 }
 
-static void
-chunk_constraint_delete_metadata(TupleInfo *ti)
-{
-	bool isnull;
-	Datum constrname = slot_getattr(ti->slot, Anum_chunk_constraint_constraint_name, &isnull);
-	int32 chunk_id = DatumGetInt32(slot_getattr(ti->slot, Anum_chunk_constraint_chunk_id, &isnull));
-	/* Get the chunk relid. Note that, at this point, the chunk table can be
-	 * deleted already */
-	Oid chunk_relid = ts_chunk_get_relid(chunk_id, true);
-
-	if (OidIsValid(chunk_relid))
-	{
-		Oid index_relid = get_constraint_index(
-			get_relation_constraint_oid(chunk_relid, NameStr(*DatumGetName(constrname)), true));
-
-		/*
-		 * If this is an index constraint, we need to cleanup the index
-		 * metadata. Don't drop the index though, since that will happen when
-		 * the constraint is dropped.
-		 */
-		if (OidIsValid(index_relid))
-			ts_chunk_index_delete(chunk_id, get_rel_name(index_relid), false);
-	}
-
-	ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
-}
-
 static void
 chunk_constraint_drop_constraint(TupleInfo *ti)
 {
@@ -961,14 +899,14 @@ chunk_constraint_drop_constraint(TupleInfo *ti)
 		};
 
 		if (OidIsValid(constrobj.objectId))
-			performDeletion(&constrobj, DROP_RESTRICT, 0);
+			/* must use DROP_CASCADE if regular table references a hypertable */
+			performDeletion(&constrobj, DROP_CASCADE, 0);
 	}
 }
 
 int
 ts_chunk_constraint_delete_by_hypertable_constraint_name(int32 chunk_id,
-														 const char *hypertable_constraint_name,
-														 bool delete_metadata, bool drop_constraint)
+														 const char *hypertable_constraint_name)
 {
 	ScanIterator iterator =
 		ts_scan_iterator_create(CHUNK_CONSTRAINT, RowExclusiveLock, CurrentMemoryContext);
@@ -984,18 +922,15 @@ ts_chunk_constraint_delete_by_hypertable_constraint_name(int32 chunk_id,
 
 		count++;
 
-		if (delete_metadata)
-			chunk_constraint_delete_metadata(ts_scan_iterator_tuple_info(&iterator));
-
-		if (drop_constraint)
-			chunk_constraint_drop_constraint(ts_scan_iterator_tuple_info(&iterator));
+		TupleInfo *ti = ts_scan_iterator_tuple_info(&iterator);
+		ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
+		chunk_constraint_drop_constraint(ti);
 	}
 	return count;
 }
 
 int
-ts_chunk_constraint_delete_by_constraint_name(int32 chunk_id, const char *constraint_name,
-											  bool delete_metadata, bool drop_constraint)
+ts_chunk_constraint_delete_by_constraint_name(int32 chunk_id, const char *constraint_name)
 {
 	ScanIterator iterator =
 		ts_scan_iterator_create(CHUNK_CONSTRAINT, RowExclusiveLock, CurrentMemoryContext);
@@ -1005,11 +940,8 @@ ts_chunk_constraint_delete_by_constraint_name(int32 chunk_id, const char *constr
 	ts_scanner_foreach(&iterator)
 	{
 		count++;
-		if (delete_metadata)
-			chunk_constraint_delete_metadata(ts_scan_iterator_tuple_info(&iterator));
-
-		if (drop_constraint)
-			chunk_constraint_drop_constraint(ts_scan_iterator_tuple_info(&iterator));
+		TupleInfo *ti = ts_scan_iterator_tuple_info(&iterator);
+		ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
 	}
 	return count;
 }
@@ -1018,11 +950,8 @@ ts_chunk_constraint_delete_by_constraint_name(int32 chunk_id, const char *constr
  * Delete all constraints for a chunk. Optionally, collect the deleted constraints.
  */
 int
-ts_chunk_constraint_delete_by_chunk_id(int32 chunk_id, ChunkConstraints *ccs, bool delete_metadata,
-									   bool drop_constraint)
+ts_chunk_constraint_delete_by_chunk_id(int32 chunk_id, ChunkConstraints *ccs, bool drop_constraint)
 {
-	Assert(delete_metadata || drop_constraint);
-
 	ScanIterator iterator =
 		ts_scan_iterator_create(CHUNK_CONSTRAINT, RowExclusiveLock, CurrentMemoryContext);
 	int count = 0;
@@ -1034,8 +963,8 @@ ts_chunk_constraint_delete_by_chunk_id(int32 chunk_id, ChunkConstraints *ccs, bo
 		count++;
 
 		ts_chunk_constraints_add_from_tuple(ccs, ts_scan_iterator_tuple_info(&iterator));
-		if (delete_metadata)
-			chunk_constraint_delete_metadata(ts_scan_iterator_tuple_info(&iterator));
+		TupleInfo *ti = ts_scan_iterator_tuple_info(&iterator);
+		ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
 
 		if (drop_constraint)
 			chunk_constraint_drop_constraint(ts_scan_iterator_tuple_info(&iterator));
@@ -1056,8 +985,9 @@ ts_chunk_constraint_delete_by_dimension_slice_id(int32 dimension_slice_id)
 	{
 		count++;
 
-		chunk_constraint_delete_metadata(ts_scan_iterator_tuple_info(&iterator));
-		chunk_constraint_drop_constraint(ts_scan_iterator_tuple_info(&iterator));
+		TupleInfo *ti = ts_scan_iterator_tuple_info(&iterator);
+		ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
+		chunk_constraint_drop_constraint(ti);
 	}
 	return count;
 }
@@ -1134,12 +1064,6 @@ chunk_constraint_rename_hypertable_from_tuple(TupleInfo *ti, const char *new_nam
 										   NameStr(new_chunk_constraint_name));
 
 	new_tuple = heap_modify_tuple(tuple, tupdesc, values, nulls, doReplace);
-
-	ts_chunk_index_adjust_meta(chunk_id,
-							   NameStr(new_hypertable_constraint_name),
-							   NameStr(*old_chunk_constraint_name),
-							   NameStr(new_chunk_constraint_name));
-
 	ts_catalog_update(ti->scanrel, new_tuple);
 	heap_freetuple(new_tuple);
 
@@ -1151,14 +1075,14 @@ chunk_constraint_rename_hypertable_from_tuple(TupleInfo *ti, const char *new_nam
  * Adjust internal metadata after index/constraint rename
  */
 int
-ts_chunk_constraint_adjust_meta(int32 chunk_id, const char *ht_constraint_name,
-								const char *old_name, const char *new_name)
+ts_chunk_constraint_adjust_meta(int32 chunk_id, const char *ht_name, const char *chunk_old_name,
+								const char *chunk_new_name)
 {
 	ScanIterator iterator =
 		ts_scan_iterator_create(CHUNK_CONSTRAINT, RowExclusiveLock, CurrentMemoryContext);
 	int count = 0;
 
-	init_scan_by_chunk_id_constraint_name(&iterator, chunk_id, old_name);
+	init_scan_by_chunk_id_constraint_name(&iterator, chunk_id, chunk_old_name);
 
 	ts_scanner_foreach(&iterator)
 	{
@@ -1178,9 +1102,9 @@ ts_chunk_constraint_adjust_meta(int32 chunk_id, const char *ht_constraint_name,
 		 * after them.
 		 */
 		NameData ht_constraint_namedata;
-		namestrcpy(&ht_constraint_namedata, ht_constraint_name);
+		namestrcpy(&ht_constraint_namedata, ht_name);
 		NameData new_namedata;
-		namestrcpy(&new_namedata, new_name);
+		namestrcpy(&new_namedata, chunk_new_name);
 
 		values[AttrNumberGetAttrOffset(Anum_chunk_constraint_hypertable_constraint_name)] =
 			NameGetDatum(&ht_constraint_namedata);
@@ -1307,8 +1231,7 @@ ts_chunk_constraint_get_name_from_hypertable_constraint(Oid chunk_relid,
 }
 
 int
-ts_chunk_constraint_delete_dimensional_constraints(int32 chunk_id, ChunkConstraints *ccs,
-												   bool delete_metadata, bool drop_constraint)
+ts_chunk_constraint_delete_dimensional_constraints(int32 chunk_id, ChunkConstraints *ccs)
 {
 	ScanIterator iterator =
 		ts_scan_iterator_create(CHUNK_CONSTRAINT, RowExclusiveLock, CurrentMemoryContext);
@@ -1329,11 +1252,8 @@ ts_chunk_constraint_delete_dimensional_constraints(int32 chunk_id, ChunkConstrai
 		count++;
 
 		ts_chunk_constraints_add_from_tuple(ccs, ti);
-		if (delete_metadata)
-			chunk_constraint_delete_metadata(ti);
-
-		if (drop_constraint)
-			chunk_constraint_drop_constraint(ti);
+		ts_catalog_delete_tid(ti->scanrel, ts_scanner_get_tuple_tid(ti));
+		chunk_constraint_drop_constraint(ti);
 	}
 	return count;
 }
@@ -1371,8 +1291,9 @@ check_chunk_constraint_violated(Oid chunk_relid, const Dimension *dim, const Dim
 	TableScanDesc scandesc;
 	bool isnull;
 
+	PushActiveSnapshot(GetLatestSnapshot());
 	rel = table_open(chunk_relid, AccessShareLock);
-	scandesc = table_beginscan(rel, GetLatestSnapshot(), 0, NULL);
+	scandesc = table_beginscan(rel, GetActiveSnapshot(), 0, NULL);
 	slot = table_slot_create(rel, NULL);
 
 	while (table_scan_getnextslot(scandesc, ForwardScanDirection, slot))
@@ -1403,6 +1324,7 @@ check_chunk_constraint_violated(Oid chunk_relid, const Dimension *dim, const Dim
 	ExecDropSingleTupleTableSlot(slot);
 	table_endscan(scandesc);
 	table_close(rel, NoLock);
+	PopActiveSnapshot();
 }
 
 /*
