@@ -83,6 +83,8 @@ CROSSMODULE_WRAPPER(array_compressor_append);
 CROSSMODULE_WRAPPER(array_compressor_finish);
 CROSSMODULE_WRAPPER(bool_compressor_append);
 CROSSMODULE_WRAPPER(bool_compressor_finish);
+CROSSMODULE_WRAPPER(uuid_compressor_append);
+CROSSMODULE_WRAPPER(uuid_compressor_finish);
 CROSSMODULE_WRAPPER(create_compressed_chunk);
 CROSSMODULE_WRAPPER(compress_chunk);
 CROSSMODULE_WRAPPER(decompress_chunk);
@@ -96,6 +98,7 @@ CROSSMODULE_WRAPPER(continuous_agg_validate_query);
 CROSSMODULE_WRAPPER(continuous_agg_get_bucket_function);
 CROSSMODULE_WRAPPER(continuous_agg_get_bucket_function_info);
 CROSSMODULE_WRAPPER(continuous_agg_migrate_to_time_bucket);
+CROSSMODULE_WRAPPER(continuous_agg_read_invalidation_record);
 CROSSMODULE_WRAPPER(cagg_try_repair);
 
 CROSSMODULE_WRAPPER(chunk_freeze_chunk);
@@ -109,11 +112,6 @@ CROSSMODULE_WRAPPER(split_chunk);
 CROSSMODULE_WRAPPER(detach_chunk);
 CROSSMODULE_WRAPPER(attach_chunk);
 
-/* hypercore */
-CROSSMODULE_WRAPPER(hypercore_handler);
-CROSSMODULE_WRAPPER(hypercore_proxy_handler);
-CROSSMODULE_WRAPPER(is_compressed_tid);
-
 /*
  * casting a function pointer to a pointer of another type is undefined
  * behavior, so we need one of these for every function type we have
@@ -131,37 +129,6 @@ error_no_default_fn_community(void)
 					 "Timescale Cloud.")));
 }
 
-static bytea *
-error_hypercore_proxy_index_options(Datum reloptions, bool validate)
-{
-	error_no_default_fn_community();
-	return NULL;
-}
-
-/*
- * An index AM always needs to return a IndexAmRoutine because the handler
- * function is invoked when the default opclass for a type is defined in
- * SQL. Therefore, return this dummy under non-TSL license and error out when
- * parsing index options instead.
- */
-static Datum
-process_hypercore_proxy_handler(PG_FUNCTION_ARGS)
-{
-	ts_license_enable_module_loading();
-
-	if (ts_cm_functions->hypercore_proxy_handler != process_hypercore_proxy_handler)
-		return ts_cm_functions->hypercore_proxy_handler(fcinfo);
-
-	IndexAmRoutine *amroutine = makeNode(IndexAmRoutine);
-
-	amroutine->amstrategies = 0;
-	amroutine->amsupport = 1;
-	amroutine->amoptsprocnum = 0;
-	amroutine->amoptions = error_hypercore_proxy_index_options;
-
-	PG_RETURN_POINTER(amroutine);
-}
-
 static bool
 error_no_default_fn_bool_void_community(void)
 {
@@ -276,24 +243,6 @@ process_cagg_try_repair(PG_FUNCTION_ARGS)
 	pg_unreachable();
 }
 
-/*
- * Ensure that the TSL library is loaded before trying to use the handler.
- *
- * As for the functions above, the TSL library might not be loaded when this
- * function is called, so we try to load this function, but fall back on the
- * Apache error message if not possible.
- */
-static Datum
-process_hypercore_handler(PG_FUNCTION_ARGS)
-{
-	ts_license_enable_module_loading();
-	if (ts_cm_functions->hypercore_handler != process_hypercore_handler)
-		return ts_cm_functions->hypercore_handler(fcinfo);
-
-	error_no_default_fn_pg_community(fcinfo);
-	pg_unreachable();
-}
-
 static DDLResult
 process_cagg_viewstmt_default(Node *stmt, const char *query_string, void *pstmt,
 							  WithClauseResult *with_clause_options)
@@ -346,6 +295,13 @@ preprocess_query_tsl_default_fn_community(Query *parse, int *cursor_opts)
 	/* No op in community licensed code */
 }
 
+static PGFunction
+bloom1_get_hash_function_default(Oid type, FmgrInfo **finfo)
+{
+	error_no_default_fn_community();
+	pg_unreachable();
+}
+
 /*
  * Define cross-module functions' default values:
  * If the submodule isn't activated, using one of the cm functions will throw an
@@ -355,8 +311,6 @@ TSDLLEXPORT CrossModuleFunctions ts_cm_functions_default = {
 	.create_upper_paths_hook = NULL,
 	.set_rel_pathlist_dml = NULL,
 	.set_rel_pathlist_query = NULL,
-	.ddl_command_start = NULL,
-	.ddl_command_end = NULL,
 	.process_altertable_cmd = NULL,
 	.process_rename_cmd = NULL,
 	.process_explain_def = NULL,
@@ -426,6 +380,7 @@ TSDLLEXPORT CrossModuleFunctions ts_cm_functions_default = {
 	.continuous_agg_get_bucket_function = error_no_default_fn_pg_community,
 	.continuous_agg_get_bucket_function_info = error_no_default_fn_pg_community,
 	.continuous_agg_migrate_to_time_bucket = error_no_default_fn_pg_community,
+	.continuous_agg_read_invalidation_record = error_no_default_fn_pg_community,
 	.cagg_try_repair = process_cagg_try_repair,
 
 	/* compression */
@@ -449,7 +404,10 @@ TSDLLEXPORT CrossModuleFunctions ts_cm_functions_default = {
 	.array_compressor_finish = error_no_default_fn_pg_community,
 	.bool_compressor_append = error_no_default_fn_pg_community,
 	.bool_compressor_finish = error_no_default_fn_pg_community,
+	.uuid_compressor_append = error_no_default_fn_pg_community,
+	.uuid_compressor_finish = error_no_default_fn_pg_community,
 	.bloom1_contains = error_no_default_fn_pg_community,
+	.bloom1_get_hash_function = bloom1_get_hash_function_default,
 
 	.decompress_batches_for_insert = error_no_default_fn_chunk_insert_state_community,
 	.init_decompress_state_for_insert = error_no_default_fn_chunk_insert_state_community,
@@ -463,10 +421,6 @@ TSDLLEXPORT CrossModuleFunctions ts_cm_functions_default = {
 	.recompress_chunk_segmentwise = error_no_default_fn_pg_community,
 	.get_compressed_chunk_index_for_recompression = error_no_default_fn_pg_community,
 
-	.hypercore_handler = process_hypercore_handler,
-	.hypercore_proxy_handler = process_hypercore_proxy_handler,
-	.is_compressed_tid = error_no_default_fn_pg_community,
-
 	.preprocess_query_tsl = preprocess_query_tsl_default_fn_community,
 	.merge_chunks = error_no_default_fn_pg_community,
 	.split_chunk = error_no_default_fn_pg_community,
