@@ -1041,6 +1041,7 @@ get_default_interval(Oid dimtype, bool adaptive_chunking)
 		case TIMESTAMPOID:
 		case TIMESTAMPTZOID:
 		case DATEOID:
+		case UUIDOID:
 			interval = adaptive_chunking ? DEFAULT_CHUNK_TIME_INTERVAL_ADAPTIVE :
 										   DEFAULT_CHUNK_TIME_INTERVAL;
 			break;
@@ -1085,7 +1086,7 @@ dimension_interval_to_internal(const char *colname, Oid dimtype, Oid valuetype,
 			interval = get_validated_integer_interval(dimtype, DatumGetInt64(value));
 			break;
 		case INTERVALOID:
-			if (!IS_TIMESTAMP_TYPE(dimtype))
+			if (!IS_TIMESTAMP_TYPE(dimtype) && !IS_UUID_TYPE(dimtype))
 				ereport(ERROR,
 						(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
 						 errmsg("invalid interval type for %s dimension", format_type_be(dimtype)),
@@ -1136,7 +1137,7 @@ dimension_add_not_null_on_column(Oid table_relid, char *colname)
 		.missing_ok = false,
 	};
 
-	ereport(NOTICE,
+	ereport(DEBUG1,
 			(errmsg("adding not-null constraint to column \"%s\"", colname),
 			 errdetail("Dimensions cannot have NULL values.")));
 
@@ -1714,11 +1715,7 @@ ts_dimension_info_out(PG_FUNCTION_ARGS)
 
 			if (OidIsValid(info->interval_type))
 			{
-				bool isvarlena;
-				Oid outfuncid;
-				getTypeOutputInfo(info->interval_type, &outfuncid, &isvarlena);
-				Assert(OidIsValid(outfuncid));
-				argvalstr = OidOutputFunctionCall(outfuncid, info->interval_datum);
+				argvalstr = ts_datum_to_string(info->interval_datum, info->interval_type);
 			}
 
 			appendStringInfo(&str,
