@@ -376,7 +376,7 @@ send_ack(dsm_segment *seg, bool success)
 	/* Send the message off, non blocking, with retries */
 	for (n = 1; n <= BGW_ACK_RETRIES; n++)
 	{
-		ack_res = shm_mq_send_compat(ack_queue_handle, sizeof(bool), &success, true);
+		ack_res = shm_mq_send(ack_queue_handle, sizeof(bool), &success, true, true);
 		if (ack_res != SHM_MQ_WOULD_BLOCK)
 			break;
 		ereport(DEBUG1, (errmsg("TimescaleDB ack message send failure, retrying")));
